@@ -4,9 +4,18 @@ package Catmandu::OCLC;
 
 Catmandu::OCLC - Catmandu modules for working with OCLC web services
 
+=begin markdown
+
+# STATUS
+[![Build Status](https://travis-ci.org/LibreCat/Catmandu-OCLC.svg)](https://travis-ci.org/LibreCat/Catmandu-OCLC)
+[![Coverage Status](https://coveralls.io/repos/LibreCat/Catmandu-OCLC/badge.svg)](https://coveralls.io/r/LibreCat/Catmandu-OCLC)
+[![Kwalitee Score](http://cpants.cpanauthors.org/dist/Catmandu-OCLC.png)](http://cpants.cpanauthors.org/dist/Catmandu-OCLC)
+
+=end markdown
+
 =cut
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 =head1 SYNOPSIS
 
@@ -45,13 +54,11 @@ L<Catmandu::Store>
 
 Patrick Hochstenbach, C<< <patrick.hochstenbach at ugent.be> >>
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See http://dev.perl.org/licenses/ for more information.
+This software is copyright (c) 2015 by Patrick Hochstenbach.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
